@@ -162,7 +162,7 @@ setMethod("collocationAnalysis", "KorAPConnection",
                 tibble()
               }
             }
-            if (maxRecurse > 0 & length(result) > 0 && any(!!as.name(thresholdScore) >= threshold)) {
+            if (maxRecurse > 0 & length(result) > 0 && any(!!thresholdScore >= threshold)) {
               recurseWith <- result %>%
                 filter(!!as.name(thresholdScore) >= threshold)
               result <- collocationAnalysis(
